@@ -1,5 +1,5 @@
 ﻿import threading, random
-from . import asynconnect
+from . import asynconnect, synconnect
 import time
 try:
 	from urllib.parse import urlparse
@@ -36,7 +36,9 @@ def select_channel (asyncons):
 class SocketPool:
 	object_timeout = 120
 	maintern_interval = 30
-	
+	use_syn_connection = False
+	ctype = None
+
 	def __init__ (self, logger, backend = False, use_pool = True):
 		self.__socketfarm = {}
 		self.__protos = {}
@@ -173,7 +175,7 @@ class SocketPool:
 		asyncon.set_active (True)		
 		return asyncon
 	
-	def create_asyncon (self, server, scheme):
+	def create_asyncon (self, server, scheme):		
 		if scheme in ("https", "wss"):
 			__conn_class = asynconnect.AsynSSLConnect
 			__dft_Port = 443
@@ -189,7 +191,12 @@ class SocketPool:
 		else:
 			__conn_class = asynconnect.AsynConnect
 			__dft_Port = 80
-		
+
+		if self.use_syn_connection:
+			if scheme == "https":
+				__conn_class = synconnect.SynSSLConnect
+			elif scheme == "http":	
+				__conn_class = synconnect.SynConnect
 		try:
 			addr, port = server.split (":", 1)
 			port = int (port)
