@@ -128,12 +128,10 @@ class DBConnect (baseconnect.BaseConnect):
     def handle_close (self, expt = None):
         if self.expt is None:
             self.expt = expt
+        self.close ()
         self.end_tran ()
-        not expt and self.close () # if expt, already closed in end_tran ()
 
     def end_tran (self):
-        if self.expt:
-            self.close ()
         self.isactive () and self.set_active (False)
 
     #-----------------------------------------------------
